@@ -256,9 +256,10 @@ ID can also be passed to these helpers:
                (coding-system-for-read 'utf-8-emacs-unix)
                (vars (prin1-to-string
                       (append (list (cons 'temporary-file-directory temporary-file-directory)
-                                    (cons 'load-path load-path)
-                                    (and (boundp 'native-comp-eln-load-path)
-                                         (cons 'native-comp-eln-load-path native-comp-eln-load-path)))
+                                    (cons 'load-path load-path))
+                              (and (boundp 'native-comp-eln-load-path)
+                                   (list
+                                    (cons 'native-comp-eln-load-path native-comp-eln-load-path)))
                               ;; NOTE: These go last so they can override the above.
                               inject-vars)))
                (libs (prin1-to-string require))
@@ -395,10 +396,6 @@ ID can also be passed to these helpers:
 Either way, return the last TEST result.
 In other words, a nil return value means it has timed out.
 
-For example, to wait on a job with the ID `:foo' to finish, you can use:
-
-    \(el-job-ng-sit-until (el-job-ng-ready-p :foo) 10)
-
 While blocking input to Emacs, keep MESSAGE visible in the echo area.
 MESSAGE can be a string, or a form that evaluates to a string.
 
